@@ -45,7 +45,6 @@
 #include "Util.h"
 
 #include <iostream>
-static DataInput::Prefs* prefs=new DataInput::Prefs();
 
 class WeightEdit : public Lum::Dlg::ValuesInput
 {
@@ -347,8 +346,8 @@ private:
 public:
   FoodFormatProvider(Lum::Model::ListTable* table)
    : table(table),
-     goodFoodColor(0.85,0.95,0.85,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
-     badFoodColor(0.95,0.85,0.85,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
+     goodFoodColor(0.82,1.0,0.82,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
+     badFoodColor(1.0,0.82,0.82,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
      goodFoodBackground(new Lum::OS::PlainFill(goodFoodColor)),
      badFoodBackground(new Lum::OS::PlainFill(badFoodColor))
   {
@@ -371,19 +370,6 @@ public:
   }
 };
 
-DataInput::Prefs::Prefs()
- : Lum::Component::Prefs(L"DataInput")
-{
-  // no code
-}
-
-void DataInput::Prefs::Initialize()
-{
-  Lum::Component::Prefs::Initialize();
-
-  frame=new Lum::OS::EmptyFrame();
-}
-
 DataInput::DataInput()
  : prevDayAction(new Lum::Model::Action()),
    todayAction(new Lum::Model::Action()),
@@ -410,8 +396,6 @@ DataInput::DataInput()
    searchTimerAction(new Lum::Model::Action()),
    trend(new Lum::Model::Int(Trend::none))
 {
-  SetPrefs(::prefs);
-
   date->SetToCurrent();
   time->SetToNow();
 
@@ -502,19 +486,18 @@ void DataInput::CalcSize()
   ft->SetFlex(true,true);
 
   headerModel=new Lum::Model::HeaderImpl();
-  headerModel->AddColumn(_(L"FOOD_TABLE_HEADER_FOOD",L"Food"),Lum::Base::Size::stdCharWidth,15,true);
+  headerModel->AddColumn(_(L"FOOD_TABLE_HEADER_FOOD",L"Food"),Lum::Base::Size::stdCharWidth,20,true);
   headerModel->AddColumn(_(L"FOOD_TABLE_HEADER_VALUE",L"Value"),Lum::Base::Size::stdCharWidth,8);
 
   table=new Lum::Table();
   table->SetFlex(true,true);
-  table->SetMinWidth(Lum::Base::Size::stdCharWidth,25);
   table->SetHeaderModel(headerModel);
   table->SetModel(foods);
   table->SetSelection(foodSelection);
   table->SetDoubleClickAction(registerFoodAction);
   table->SetShowHeader(true);
   table->GetTableView()->SetAutoFitColumns(true);
-  //table->GetTableView()->SetAutoHSize(true);
+  table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetFormatProvider(new FoodFormatProvider(foods));
   ft->Add(table);
 
@@ -582,14 +565,13 @@ void DataInput::CalcSize()
 
   table=new Lum::Table();
   table->SetFlex(true,true);
-  table->SetMinWidth(Lum::Base::Size::stdCharWidth,30);
   table->SetHeaderModel(headerModel);
   table->SetModel(entries);
   table->SetSelection(entrySelection);
   table->SetDoubleClickAction(editItemAction);
   table->SetShowHeader(true);
   table->GetTableView()->SetAutoFitColumns(true);
-  //table->GetTableView()->SetAutoHSize(true);
+  table->GetTableView()->SetAutoHSize(true);
   et->Add(table);
 
   menu=new Lum::Menu();
