@@ -30,14 +30,6 @@
 
 class DataInput : public Lum::Component
 {
-public:
-  class Prefs : public Lum::Component::Prefs
-  {
-  public:
-    Prefs();
-    void Initialize();
-  };
-
 private:
   Lum::Model::ActionRef              prevDayAction;
   Lum::Model::ActionRef              todayAction;
