@@ -27,19 +27,9 @@
 #include "Configuration.h"
 #include "Util.h"
 
-static Diagram::Prefs *prefs=new Diagram::Prefs();
-
 // We resync our self with the date on the first draw
 static bool adjusted=false;
 
-void Diagram::Prefs::Initialize()
-{
-  Lum::Scrollable::Prefs::Initialize();
-
-  background=Lum::OS::display->GetFill(Lum::OS::Display::graphBackgroundFillIndex);
-  frame=Lum::OS::display->GetFrame(Lum::OS::Display::listboxFrameIndex);
-}
-
 double exponent(double x)
 {
   if (x>=0) {
@@ -59,7 +49,7 @@ Diagram::Diagram()
    valueBadFrameColor(0.8,0.58,0.58,Lum::OS::display->blackColor),
    mode(modeFullDay)
 {
-  SetPrefs(::prefs);
+  SetBackground(Lum::OS::display->GetFill(Lum::OS::Display::graphBackgroundFillIndex));
 
   AttachModel(topWeight);
   AttachModel(bottomWeight);
@@ -161,7 +151,7 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
   bool                                               pointsDrawn=false; // We have drawn at least one point
   bool                                               pastEnd=false;     // We have beenmoved past the visible end
   bool                                               finished=false;    // We have drawn one point pastthe visible end and can now finish
-  int                                                px=0,py=0;
+  int                                                px=0,py=0;         // Coordinates of previous point
   Lum::Base::Calendar                                day;
   Value                                              lastWeight=0;
 
@@ -264,7 +254,7 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
           draw->PushForeground(Lum::OS::Display::blackColor);
         }
 
-        int cx,cy;
+        int cx,cy; // Coordinates of current point
 
         cx=xPos+days*dayWidth+(entry->time.GetHour()*dayWidth)/24;
         cy=this->y+TransformWeight(entry->amount);
@@ -273,8 +263,10 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
                       cy-3,
                       6,6,
                       0,360*64);
+
         draw->PopForeground();
 
+        // Draw line between previous and current weight point
         if (pointsDrawn) {
           int lx1, ly1, lx2, ly2;
 
@@ -285,27 +277,32 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
           lx2=cx;
           ly2=cy;
 
-          if (lx1<this->x) {
-            lx1=this->x;
-            ly1=(lx1-px)*(cy-py)/(cx-px)+py;
-          }
+          if (!(lx1<this->x && lx2<this->x)) {
+            // Point outside diagram: Interpolate position on left diagram border
+            if (lx1<this->x) {
+              lx1=this->x;
+              ly1=((lx1-px)*(cy-py))/(cx-px)+py;
+            }
 
-          if (lx2>this->x+this->width-1) {
-            lx2=this->x+this->width-1;
-            ly2=(lx2-px)*(cy-py)/(cx-px)+py;
-          }
+            // Point outside diagram: Interpolate position on right diagram border
+            if (lx2>this->x+this->width-1) {
+              lx2=this->x+this->width-1;
+              ly2=((lx2-px)*(cy-py))/(cx-px)+py;
+            }
 
-          if(lastWeight<minWeight->Get() || lastWeight>maxWeight->Get() ||
-             entry->amount<minWeight->Get() || entry->amount>maxWeight->Get()) {
-            draw->PushForeground(warnColor);
+            if(lastWeight<minWeight->Get() || lastWeight>maxWeight->Get() ||
+               entry->amount<minWeight->Get() || entry->amount>maxWeight->Get()) {
+              draw->PushForeground(warnColor);
+            }
+            else {
+              draw->PushForeground(Lum::OS::Display::blackColor);
+            }
+
+            draw->PushPen(2,Lum::OS::DrawInfo::penRound);
+            draw->DrawLine(lx1,ly1,lx2,ly2);
+            draw->PopPen();
+            draw->PopForeground();
           }
-          else {
-            draw->PushForeground(Lum::OS::Display::blackColor);
-          }
-          draw->PushPen(2,Lum::OS::DrawInfo::penRound);
-          draw->DrawLine(lx1,ly1,lx2,ly2);
-          draw->PopPen();
-          draw->PopForeground();
         }
 
         pointsDrawn=true;
@@ -500,7 +497,7 @@ void Diagram::Draw(int x, int y, size_t w, size_t h)
 {
   Lum::Scrollable::Draw(x,y,w,h);
 
-  if (!Intersect(x,y,w,h)) {
+  if (!OIntersect(x,y,w,h)) {
     return;
   }
 
