@@ -24,13 +24,6 @@
 
 class Diagram : public Lum::Scrollable
 {
-public:
-  class Prefs : public Lum::Scrollable::Prefs
-  {
-  public:
-    void Initialize();
-  };
-
 private:
   enum Mode {
     modeFullDay  = 0,
