@@ -23,6 +23,7 @@
 
 #include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
+#include <Lum/Combo.h>
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
@@ -48,9 +49,13 @@ Preferences::Preferences()
   minValue(new Lum::Model::String(AmountToString(::minValue->Get()))),
   goodValueLimit(new Lum::Model::String(ValueToString(::goodValueLimit->Get()))),
   badValueLimit(new Lum::Model::String(ValueToString(::badValueLimit->Get()))),
+  refValue(new Lum::Model::String(ValueToString(::refValue->Get()))),
   valueUnit(new Lum::Model::String(::valueUnit->Get())),
   weightUnit(new Lum::Model::String(::weightUnit->Get()))
 {
+  trendType->Push();
+  trendDirection->Push();
+
   AttachModel(okAction);
 
   AttachModel(topWeight);
@@ -65,6 +70,8 @@ Preferences::Preferences()
   AttachModel(goodValueLimit);
   AttachModel(badValueLimit);
 
+  AttachModel(refValue);
+
   AttachModel(valueUnit);
   AttachModel(weightUnit);
 
@@ -73,9 +80,14 @@ Preferences::Preferences()
 
 Preferences::~Preferences()
 {
+  trendDirection->Pop();
+  trendType->Pop();
+
   UnattachModel(weightUnit);
   UnattachModel(valueUnit);
 
+  UnattachModel(refValue);
+
   UnattachModel(minValue);
   UnattachModel(maxValue);
   UnattachModel(bottomValue);
@@ -93,13 +105,15 @@ Preferences::~Preferences()
 
 void Preferences::PreInit()
 {
-  Lum::Button      *button;
-  Lum::ButtonRow   *buttonRow;
-  Lum::Label       *label;
-  Lum::Panel       *panel,*panel2;
-  Lum::String      *string;
-  Lum::Tab         *tab;
-  Lum::WindowGroup *windowGroup;
+  Lum::Button               *button;
+  Lum::ButtonRow            *buttonRow;
+  Lum::Combo                *combo;
+  Lum::Label                *label;
+  Lum::Panel                *panel,*panel2;
+  Lum::String               *string;
+  Lum::Tab                  *tab;
+  Lum::WindowGroup          *windowGroup;
+  Lum::Model::ListTableRef  table;
 
   panel=new Lum::VPanel();
 
@@ -110,13 +124,11 @@ void Preferences::PreInit()
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
-  string->RequestFocus();
   string->SetModel(valueUnit);
   label->AddLabel(_(L"PREFS_LABEL_VALUE_UNIT",L"Value unit:"),string);
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
-  string->RequestFocus();
   string->SetModel(weightUnit);
   label->AddLabel(_(L"PREFS_LABEL_WEIGHT_UNIT",L"Weight unit:"),string);
 
@@ -129,7 +141,6 @@ void Preferences::PreInit()
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
-  string->RequestFocus();
   string->SetAlignment(Lum::String::right);
   string->SetModel(bottomWeight);
   panel2->Add(string);
@@ -140,7 +151,6 @@ void Preferences::PreInit()
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
-  string->RequestFocus();
   string->SetAlignment(Lum::String::right);
   string->SetModel(topWeight);
   panel2->Add(string);
@@ -151,7 +161,6 @@ void Preferences::PreInit()
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
-  string->RequestFocus();
   string->SetAlignment(Lum::String::right);
   string->SetModel(minWeight);
   panel2->Add(string);
@@ -162,7 +171,6 @@ void Preferences::PreInit()
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
-  string->RequestFocus();
   string->SetAlignment(Lum::String::right);
   string->SetModel(maxWeight);
   panel2->Add(string);
@@ -177,7 +185,6 @@ void Preferences::PreInit()
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
-  string->RequestFocus();
   string->SetAlignment(Lum::String::right);
   string->SetModel(bottomValue);
   panel2->Add(string);
@@ -188,7 +195,6 @@ void Preferences::PreInit()
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
-  string->RequestFocus();
   string->SetAlignment(Lum::String::right);
   string->SetModel(topValue);
   panel2->Add(string);
@@ -199,7 +205,6 @@ void Preferences::PreInit()
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
-  string->RequestFocus();
   string->SetAlignment(Lum::String::right);
   string->SetModel(minValue);
   panel2->Add(string);
@@ -210,7 +215,6 @@ void Preferences::PreInit()
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
-  string->RequestFocus();
   string->SetAlignment(Lum::String::right);
   string->SetModel(maxValue);
   panel2->Add(string);
@@ -219,20 +223,47 @@ void Preferences::PreInit()
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
-  string->RequestFocus();
   string->SetAlignment(Lum::String::right);
   string->SetModel(goodValueLimit);
   label->AddLabel(_(L"PREFS_LABEL_GOOD_VALUE_LIMIT",L"Limit for good values:"),string);
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
-  string->RequestFocus();
   string->SetAlignment(Lum::String::right);
   string->SetModel(badValueLimit);
   label->AddLabel(_(L"PREFS_LABEL_BAD_VALUE_LIMIT",L"Limit for bad values:"),string);
 
   tab->Add(_(L"PREFS_LABEL_VALUES",L"Values"),label);
 
+  label=new Lum::Label();
+  label->SetFlex(true,true);
+
+  string=new Lum::String();
+  string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
+  string->SetAlignment(Lum::String::right);
+  string->SetModel(refValue);
+  label->AddLabel(_(L"PREFS_LABEL_REF_VALUE",L"Referenz for trend:"),string);
+
+  table=new Lum::Model::ListTable(1);
+  table->AppendString(_(L"PREFS_LABEL_TREND_TYPE_REFREL",L"Relative to reference"));
+  table->AppendString(_(L"PREFS_LABEL_TREND_TYPE_TWOWEEK",L"2 week trend"));
+
+  combo=new Lum::IndexCombo();
+  combo->SetModel(trendType);
+  combo->SetTableModel(table);
+  label->AddLabel(_(L"PREFS_LABEL_TREND_TYPE",L"Trend type:"),combo);
+
+  table=new Lum::Model::ListTable(1);
+  table->AppendString(_(L"PREFS_LABEL_TREND_DIR_DOWN",L"Lower is better"));
+  table->AppendString(_(L"PREFS_LABEL_TREND_DIR_UP",L"Higher is better"));
+
+  combo=new Lum::IndexCombo();
+  combo->SetModel(trendDirection);
+  combo->SetTableModel(table);
+  label->AddLabel(_(L"PREFS_LABEL_TREND_DIR",L"Trend direction:"),combo);
+
+  tab->Add(_(L"PREFS_LABEL_TREND",L"Trend"),label);
+
   panel->Add(tab);
 
   panel->Add(new Lum::VSpace());
@@ -242,18 +273,16 @@ void Preferences::PreInit()
 
   button=new Lum::Button();
   button->SetFlex(true,true);
-  button->RequestFocus();
   button->SetModel(okAction);
   button->SetType(Lum::Button::typeCommit);
-  button->SetText(L"_OK");
+  button->SetText(_ld(dlgButtonOk));
   buttonRow->Add(button);
 
   button=new Lum::Button();
   button->SetFlex(true,true);
-  button->RequestFocus();
   button->SetModel(GetClosedAction());
   button->SetType(Lum::Button::typeCancel);
-  button->SetText(L"_Cancel");
+  button->SetText(_ld(dlgButtonCancel));
   buttonRow->Add(button);
 
   panel->Add(buttonRow);
@@ -290,6 +319,7 @@ void Preferences::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& ms
         StringToAmount(minValue->Get(),tmp) &&
         StringToAmount(goodValueLimit->Get(),gVL) &&
         StringToAmount(badValueLimit->Get(),bVL) &&
+        StringToAmount(refValue->Get(),tmp) &&
         topW>bottomW &&
         topV>bottomV &&
         gVL<bVL) {
@@ -300,7 +330,7 @@ void Preferences::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& ms
     }
   }
   else if (model==okAction && okAction->IsFinished()) {
-    size_t topW,bottomW,maxW,minW,topV,bottomV,maxV,minV,goodVL,badVL;
+    size_t topW,bottomW,maxW,minW,topV,bottomV,maxV,minV,goodVL,badVL,refV;
 
     assert(StringToAmount(topWeight->Get(),topW) &&
            StringToAmount(bottomWeight->Get(),bottomW) &&
@@ -311,7 +341,8 @@ void Preferences::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& ms
            StringToAmount(maxValue->Get(),maxV) &&
            StringToAmount(minValue->Get(),minV) &&
            StringToAmount(goodValueLimit->Get(),goodVL) &&
-           StringToAmount(badValueLimit->Get(),badVL));
+           StringToAmount(badValueLimit->Get(),badVL) &&
+           StringToAmount(refValue->Get(),refV));
 
     ::valueUnit->Set(valueUnit->Get());
     ::weightUnit->Set(weightUnit->Get());
@@ -328,6 +359,11 @@ void Preferences::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& ms
     ::goodValueLimit->Set(goodVL);
     ::badValueLimit->Set(badVL);
 
+    ::refValue->Set(refV);
+
+    trendType->Save();
+    trendDirection->Save();
+
     Exit();
   }
 
